.. Gammy documentation master file, created by
   sphinx-quickstart on Mon Sep 20 08:39:17 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Gammy documentation
===================

A Generalized additive model is a predictive mathematical model defined as a sum
of terms that are calibrated (fitted) with observation data. This package
provides a hopefully pleasant interface for configuring and fitting such models.
Bayesian interpretation of model parameters and a minimalist set of
features are promoted.

The main idea behind Gammy is to enable `quick` coding of the solution
to most of the day-to-day lightweight linear model estimation problems.


Contents
--------

.. toctree::
   installation
   features
   backlog
   api
   :maxdepth: 2


Other Python projects with GAM functionalities
##############################################

- `PyGAM <https://pygam.readthedocs.io/en/latest/>`_
- `Statsmodels <https://www.statsmodels.org/dev/gam.html>`_
- `BlinPy <https://github.com/solbes/blinpy>`_
